==> storage_local-0.1.56-py3-none-any.whl: storage_local/aws_s3_storage_local/AWSStorage.py <==
import os

import boto3
from logger_local.MetaLogger import MetaLogger
from python_sdk_remote.utilities import our_get_env
from database_mysql_local.generic_crud import GenericCRUD

from .StorageConstants import STORAGE_TYPE_ID, FILE_TYPE_ID, LOGGER_CODE_OBJECT
from .StorageDB import StorageDB
from .StorageInterface import StorageInterface
from .StorageConstants import ExtensionsEnum


AWS_ACCESS_KEY_ID = our_get_env("AWS_ACCESS_KEY_ID")
AWS_SECRET_ACCESS_KEY = our_get_env("AWS_SECRET_ACCESS_KEY")


class AwsS3Storage(StorageInterface, GenericCRUD, metaclass=MetaLogger, object=LOGGER_CODE_OBJECT):

    def __init__(self, bucket_name: str, region: str, is_test_data=False) -> None:
        GenericCRUD.__init__(self, default_schema_name='storage',
                             default_table_name='storage_table',
                             default_view_table_name='storage_view',
                             is_test_data=is_test_data)
        self.region = region
        self.bucket_name = bucket_name
        self.storage_id_column_name = 'storage_id'
        self.storage_database = StorageDB()
        self.boto3_client = boto3.client('s3',
                                   aws_access_key_id=AWS_ACCESS_KEY_ID,
                                   aws_secret_access_key=AWS_SECRET_ACCESS_KEY)

    @staticmethod
    # TODO Move this method out of this class
    def get_filename_from_path(path: str) -> str:
        return os.path.basename(path)

    # TODO We should allow to add url without local_file_path and remote_path, please add such test and make sure we support it.
    def upload_file(self, *, local_file_path: str, remote_path: str, url: str = None) -> int or None:
        """uploads file to S3"""
        read_binary = 'rb'
        filename = self.get_filename_from_path(local_file_path)
        # determine type of file
        ext=os.path.splitext(local_file_path)[1]
        with open(local_file_path, read_binary) as file_obj:
            file_contents = file_obj.read()

        # Upload the file to S3 with the CRC32 checksum
        response = self.boto3_client.put_object(
            Bucket=self.bucket_name,
            Key=remote_path + filename,
            Body=file_contents,
            ChecksumAlgorithm='crc32'
        )


        if 'ETag' in response:
            # TODO: constracts should be replaced with parameters
            storage_id = self.storage_database.upload_to_database(file_path=remote_path, filename=filename,
                                                                  region=self.region, storage_type_id=STORAGE_TYPE_ID,
                                                                  file_type_id=FILE_TYPE_ID, extension_id=(self.get_eum_by_extension(ext)),
                                                                  url=url)
            return storage_id
        return None

    # download a file from s3 to local_file_path
    def download_file(self, remote_path: str, local_file_path: str) -> None:
        self.boto3_client.download_file(self.bucket_name, remote_path, local_file_path)


    def download_file_by_storage_id(self, storage_id: int, local_file_path: str):
        remote_path_dict = super().select_one_dict_by_column_and_value(schema_name=self.default_schema_name, 
                                                    view_table_name=self.default_view_table_name,
                                                    column_name=self.storage_id_column_name,
                                                    column_value=storage_id,
                                                    select_clause_value="path,filename")
        remote_path = os.path.join(remote_path_dict["path"], remote_path_dict["filename"])
        self.boto3_client.download_file(self.bucket_name, remote_path, local_file_path)
        

    # logical delete

    def delete_by_remote_path_filename(self, remote_path: str, filename: str) -> None:
        self.storage_database.delete(remote_path=remote_path, filename=filename, region=self.region)
    
    def delete_by_storage_id(self, storage_id: str, filename: str) -> None:
        self.storage_database.delete(remote_path=storage_id, filename=filename, region=self.region)

    def get_eum_by_extension(file_extension) -> int:
        if file_extension == '.txt':
            return ExtensionsEnum.txt.value
        if file_extension == '.doc':
            return ExtensionsEnum.doc.value
        if file_extension == '.pdf':
            return ExtensionsEnum.pdf.value
        if file_extension == '.xls':
            return ExtensionsEnum.xls.value
        if file_extension == '.jpg':
            return ExtensionsEnum.jpg.value
        else:
            raise ValueError(f"Unsupported file extension: {file_extension}")

==> storage_local-0.1.58-py3-none-any.whl: storage_local/aws_s3_storage_local/AWSStorage.py <==
import os

import boto3
from logger_local.MetaLogger import MetaLogger
from python_sdk_remote.utilities import our_get_env
from database_mysql_local.generic_crud import GenericCRUD

from .StorageConstants import STORAGE_TYPE_ID, FILE_TYPE_ID, LOGGER_CODE_OBJECT
from .StorageDB import StorageDB
from .StorageInterface import StorageInterface
from .StorageConstants import ExtensionsEnum


AWS_ACCESS_KEY_ID = our_get_env("AWS_ACCESS_KEY_ID")
AWS_SECRET_ACCESS_KEY = our_get_env("AWS_SECRET_ACCESS_KEY")


class AwsS3Storage(StorageInterface, GenericCRUD, metaclass=MetaLogger, object=LOGGER_CODE_OBJECT):

    def __init__(self, bucket_name: str, region: str, is_test_data=False) -> None:
        GenericCRUD.__init__(self, default_schema_name='storage',
                             default_table_name='storage_table',
                             default_view_table_name='storage_view',
                             is_test_data=is_test_data)
        self.region = region
        self.bucket_name = bucket_name
        self.storage_id_column_name = 'storage_id'
        self.storage_database = StorageDB()
        self.boto3_client = boto3.client('s3',
                                   aws_access_key_id=AWS_ACCESS_KEY_ID,
                                   aws_secret_access_key=AWS_SECRET_ACCESS_KEY)

    @staticmethod
    # TODO Move this method out of this class
    def get_filename_from_path(path: str) -> str:
        return os.path.basename(path)

    # TODO We should allow to add url without local_file_path and remote_path, please add such test and make sure we support it.
    def upload_file(self, *, local_file_path: str, remote_path: str, url: str = None) -> int or None:
        """uploads file to S3"""
        read_binary = 'rb'
        filename = self.get_filename_from_path(local_file_path)
        # determine type of file
        ext=os.path.splitext(local_file_path)[1]
        with open(local_file_path, read_binary) as file_obj:
            file_contents = file_obj.read()

        # Upload the file to S3 with the CRC32 checksum
        response = self.boto3_client.put_object(
            Bucket=self.bucket_name,
            Key=remote_path + filename,
            Body=file_contents,
            ChecksumAlgorithm='crc32'
        )


        if 'ETag' in response:
            # TODO: constracts should be replaced with parameters
            storage_id = self.storage_database.upload_to_database(file_path=remote_path, filename=filename,
                                                                  region=self.region, storage_type_id=STORAGE_TYPE_ID,
                                                                  file_type_id=FILE_TYPE_ID, extension_id=(self.get_eum_by_extension(ext)),
                                                                  url=url)
            return storage_id
        return None

    # download a file from s3 to local_file_path
    def download_file(self, remote_path: str, local_file_path: str) -> None:
        self.boto3_client.download_file(self.bucket_name, remote_path, local_file_path)
        

    # logical delete

    def delete_by_remote_path_filename(self, remote_path: str, filename: str) -> None:
        self.storage_database.delete(remote_path=remote_path, filename=filename, region=self.region)
    
    def delete_by_storage_id(self, storage_id: int) -> None:
        remote_path = self.select_one_value_by_column_and_value(schema_name=self.default_schema_name,
                                                  view_table_name=self.default_view_table_name,
                                                  select_clause_value="path",
                                                  column_name="storage_id",
                                                  column_value=storage_id)
        filename = self.select_one_value_by_column_and_value(schema_name=self.default_schema_name,
                                                  view_table_name=self.default_view_table_name,
                                                  select_clause_value="filename",
                                                  column_name="storage_id",
                                                  column_value=storage_id)
        return self.storage_database.delete(remote_path=remote_path, filename=filename, region=self.region)

    def get_eum_by_extension(file_extension) -> int:
        if file_extension == '.txt':
            return ExtensionsEnum.txt.value
        if file_extension == '.doc':
            return ExtensionsEnum.doc.value
        if file_extension == '.pdf':
            return ExtensionsEnum.pdf.value
        if file_extension == '.xls':
            return ExtensionsEnum.xls.value
        if file_extension == '.jpg':
            return ExtensionsEnum.jpg.value
        else:
            raise ValueError(f"Unsupported file extension: {file_extension}")
